@@ -1,8 +1,6 @@
 #!/usr/bin/env python
 import json
-
-import requests
-import xlrd
+import pandas
 
 
 URL = "https://www.betaalvereniging.nl/wp-content/uploads/BIC-lijst-NL.xlsx"
@@ -11,25 +9,25 @@ URL = "https://www.betaalvereniging.nl/wp-content/uploads/BIC-lijst-NL.xlsx"
 def process():
     registry = []
 
-    book = xlrd.open_workbook(file_contents=requests.get(URL).content)
-    sheet = book.sheet_by_index(0)
+    datas = pandas.read_excel(URL, skiprows=3, sheet_name=0, dtype=str)
+    datas = datas.dropna(how="all")
+    datas.fillna("", inplace=True)
 
-    for row in list(sheet.get_rows())[4:]:
+    for row in datas.itertuples(index=False):
         bic, bank_code, name = row[:3]
 
-        if not any((bic.value, bank_code.value, name.value)):
-            continue
-
         registry.append(
             {
                 "country_code": "NL",
                 "primary": True,
-                "bic": bic.value.upper(),
-                "bank_code": bank_code.value,
-                "name": name.value,
-                "short_name": name.value,
+                "bic": str(bic).upper(),
+                "bank_code": bank_code,
+                "name": str(name).strip(),
+                "short_name": str(name).strip(),
             }
         )
+
+    print(f"Fetched {len(registry)} bank records")
     return registry
 
 
